@@ -22,6 +22,7 @@
 
 import sys, os, glob, fnmatch, tempfile
 import subprocess
+import re
 
 EGGing = 'bdist_egg' in sys.argv or 'egg_info' in sys.argv
 if not EGGing:
@@ -811,7 +812,10 @@ class MyUnixCCompiler(distutils.unixccompiler.UnixCCompiler):
         compiler_so = self.compiler_so
         if sys.platform == 'darwin':           
             compiler_so = _darwin_compiler_fixup(compiler_so, cc_args + extra_postargs)
-
+        # Mandriva / Mageia Hack ------------------------------------
+        #self.linker_so = [el for el in self.linker_so if el != '-Wl,--no-undefined']
+        #compiler_so = [el for el in compiler_so if el != '-Werror=format-security']
+        # Mandriva / Mageia Hack ------------------------------------
         try:
             self.spawn(compiler_so + cc_args + [src, '-o', obj] +
                        extra_postargs)
@@ -1056,10 +1060,9 @@ elif os.name == 'posix' or COMPILER == 'mingw32':
         libs = ['stdc++']
         NO_SCRIPTS = 1
         if ARCH != "":
-            cflags.append("-arch")
-            cflags.append(ARCH)
-            lflags.append("-arch")
-            lflags.append(ARCH)
+            splitArch = "-arch " + re.sub(","," -arch ",ARCH)
+            cflags.extend(splitArch.split(' '))
+            lflags.extend(splitArch.split(' '))
 
         if not os.environ.get('CC') or not os.environ.get('CXX'):
             os.environ["CXX"] = getWxConfigValue('--cxx')
